# Generated by Django 4.2.16 on 2024-12-02 20:53

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0122_alter_ticketnote_title'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='account',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='account_projects', to='djautotask.account'),
        ),
        migrations.AlterField(
            model_name='task',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='project_tasks', to='djautotask.project'),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='account',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='account_tickets', to='djautotask.account'),
        ),
    ]
