# Generated by Django 4.2.16 on 2024-11-04 15:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0120_merge_20241101_1316'),
        ('djautotask', '0120_resource_title'),
    ]

    operations = [
    ]
